This module contains all of the filesystem scanner modules
The most common scanner to use is generic::Scanner which will automatically detect and use the appropriate scanner.
Modules
- collection
- The collection scanner will scan a folder and its children
- episode
- The episode scanner will scan a folder and exit
- generic
- The generic scanner will scan a directory and automatically detect the type of media, deferring to the correct scanner.
- library
- The library scanner will scan an entire directory using the generic scanner
- movie
- The movie scanner will scan a folder and exit
- season
- The episode scanner will scan a folder and its children
- show
- The show scanner will scan a folder and its children
Structs
- Collection
Scan - A scanned collection
- Episode
Scan - A scanned episode
- Movie
Scan - A scanned movie
- Season
Scan - A scanned season
- Show
Scan - A scanned show
Enums
- Media
Ref - A reference to a piece of media